==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PoraDnia.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class PoraDnia extends GenericDPSObject {
    /**
     * PORA_DNIA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * PORA_DNIA.CZY_AKTUALNA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean czyAktualna;

    /**
     * PORA_DNIA.GODZINA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer godzina;

    /**
     * PORA_DNIA.KOLEJNOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer kolejnosc;

    /**
     * PORA_DNIA.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * PORA_DNIA.SKROT
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String skrot;

    /**
     * PORA_DNIA.WRP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean wrp;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PORA_DNIA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * PORA_DNIA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return PORA_DNIA.CZY_AKTUALNA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getCzyAktualna() {
        return czyAktualna;
    }

    /**
     * PORA_DNIA.CZY_AKTUALNA
     *
     * @param czyAktualna
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setCzyAktualna(Boolean czyAktualna) {
        this.czyAktualna = czyAktualna;
    }

    /**
     * @return PORA_DNIA.GODZINA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getGodzina() {
        return godzina;
    }

    /**
     * PORA_DNIA.GODZINA
     *
     * @param godzina
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setGodzina(Integer godzina) {
        this.godzina = godzina;
    }

    /**
     * @return PORA_DNIA.KOLEJNOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getKolejnosc() {
        return kolejnosc;
    }

    /**
     * PORA_DNIA.KOLEJNOSC
     *
     * @param kolejnosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKolejnosc(Integer kolejnosc) {
        this.kolejnosc = kolejnosc;
    }

    /**
     * @return PORA_DNIA.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * PORA_DNIA.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return PORA_DNIA.SKROT
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getSkrot() {
        return skrot;
    }

    /**
     * PORA_DNIA.SKROT
     *
     * @param skrot
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSkrot(String skrot) {
        this.skrot = skrot == null ? null : skrot.trim();
    }

    /**
     * @return PORA_DNIA.WRP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getWrp() {
        return wrp;
    }

    /**
     * PORA_DNIA.WRP
     *
     * @param wrp
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWrp(Boolean wrp) {
        this.wrp = wrp;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PoraDnia other = (PoraDnia) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getCzyAktualna() == null ? other.getCzyAktualna() == null : this.getCzyAktualna().equals(other.getCzyAktualna()))
            && (this.getGodzina() == null ? other.getGodzina() == null : this.getGodzina().equals(other.getGodzina()))
            && (this.getKolejnosc() == null ? other.getKolejnosc() == null : this.getKolejnosc().equals(other.getKolejnosc()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getSkrot() == null ? other.getSkrot() == null : this.getSkrot().equals(other.getSkrot()))
            && (this.getWrp() == null ? other.getWrp() == null : this.getWrp().equals(other.getWrp()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getCzyAktualna() == null) ? 0 : getCzyAktualna().hashCode());
        result = prime * result + ((getGodzina() == null) ? 0 : getGodzina().hashCode());
        result = prime * result + ((getKolejnosc() == null) ? 0 : getKolejnosc().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getSkrot() == null) ? 0 : getSkrot().hashCode());
        result = prime * result + ((getWrp() == null) ? 0 : getWrp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", czyAktualna=").append(czyAktualna);
        sb.append(", godzina=").append(godzina);
        sb.append(", kolejnosc=").append(kolejnosc);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", skrot=").append(skrot);
        sb.append(", wrp=").append(wrp);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PoraDnia.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class PoraDnia extends GenericDPSObject {
    /**
     * PORA_DNIA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * PORA_DNIA.CZY_AKTUALNA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean czyAktualna;

    /**
     * PORA_DNIA.GODZINA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer godzina;

    /**
     * PORA_DNIA.KOLEJNOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer kolejnosc;

    /**
     * PORA_DNIA.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * PORA_DNIA.SKROT
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String skrot;

    /**
     * PORA_DNIA.WRP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean wrp;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PORA_DNIA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * PORA_DNIA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return PORA_DNIA.CZY_AKTUALNA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getCzyAktualna() {
        return czyAktualna;
    }

    /**
     * PORA_DNIA.CZY_AKTUALNA
     *
     * @param czyAktualna
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setCzyAktualna(Boolean czyAktualna) {
        this.czyAktualna = czyAktualna;
    }

    /**
     * @return PORA_DNIA.GODZINA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getGodzina() {
        return godzina;
    }

    /**
     * PORA_DNIA.GODZINA
     *
     * @param godzina
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setGodzina(Integer godzina) {
        this.godzina = godzina;
    }

    /**
     * @return PORA_DNIA.KOLEJNOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getKolejnosc() {
        return kolejnosc;
    }

    /**
     * PORA_DNIA.KOLEJNOSC
     *
     * @param kolejnosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKolejnosc(Integer kolejnosc) {
        this.kolejnosc = kolejnosc;
    }

    /**
     * @return PORA_DNIA.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * PORA_DNIA.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return PORA_DNIA.SKROT
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getSkrot() {
        return skrot;
    }

    /**
     * PORA_DNIA.SKROT
     *
     * @param skrot
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSkrot(String skrot) {
        this.skrot = skrot == null ? null : skrot.trim();
    }

    /**
     * @return PORA_DNIA.WRP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getWrp() {
        return wrp;
    }

    /**
     * PORA_DNIA.WRP
     *
     * @param wrp
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWrp(Boolean wrp) {
        this.wrp = wrp;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PoraDnia other = (PoraDnia) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getCzyAktualna() == null ? other.getCzyAktualna() == null : this.getCzyAktualna().equals(other.getCzyAktualna()))
            && (this.getGodzina() == null ? other.getGodzina() == null : this.getGodzina().equals(other.getGodzina()))
            && (this.getKolejnosc() == null ? other.getKolejnosc() == null : this.getKolejnosc().equals(other.getKolejnosc()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getSkrot() == null ? other.getSkrot() == null : this.getSkrot().equals(other.getSkrot()))
            && (this.getWrp() == null ? other.getWrp() == null : this.getWrp().equals(other.getWrp()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getCzyAktualna() == null) ? 0 : getCzyAktualna().hashCode());
        result = prime * result + ((getGodzina() == null) ? 0 : getGodzina().hashCode());
        result = prime * result + ((getKolejnosc() == null) ? 0 : getKolejnosc().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getSkrot() == null) ? 0 : getSkrot().hashCode());
        result = prime * result + ((getWrp() == null) ? 0 : getWrp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", czyAktualna=").append(czyAktualna);
        sb.append(", godzina=").append(godzina);
        sb.append(", kolejnosc=").append(kolejnosc);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", skrot=").append(skrot);
        sb.append(", wrp=").append(wrp);
        sb.append("]");
        return sb.toString();
    }
}
